@@ -30,7 +30,7 @@
 
 # Following three lines added so that sphinx autodocumentation works. 
 import os
-os.environ['DJANGO_SETTINGS_MODULE'] = 'openrem.settings'
+os.environ['DJANGO_SETTINGS_MODULE'] = 'openremproject.settings'
 from django.db import models
 
 import django_filters
@@ -47,10 +47,10 @@ class RFSummaryListFilter(django_filters.FilterSet):
     study_description = django_filters.CharFilter(lookup_type='icontains', label='Study description')
     patient_age_min = django_filters.NumberFilter(lookup_type='gt', label='Min age (yrs)', name='patient_study_module_attributes__patient_age_decimal')
     patient_age_max = django_filters.NumberFilter(lookup_type='lt', label='Max age (yrs)', name='patient_study_module_attributes__patient_age_decimal')
-    general_equipment_module_attributes__institution_name = django_filters.CharFilter(lookup_type='icontains', label='Hospital')
-    general_equipment_module_attributes__manufacturer = django_filters.CharFilter(lookup_type='icontains', label='Manufacturer')
-    general_equipment_module_attributes__manufacturer_model_name = django_filters.CharFilter(lookup_type='icontains', label='Model')
-    general_equipment_module_attributes__station_name = django_filters.CharFilter(lookup_type='icontains', label='Station name')
+    institution_name = django_filters.CharFilter(lookup_type='icontains', label='Hospital', name='general_equipment_module_attributes__institution_name')
+    manufacturer = django_filters.CharFilter(lookup_type='icontains', label='Manufacturer', name='general_equipment_module_attributes__manufacturer')
+    model_name = django_filters.CharFilter(lookup_type='icontains', label='Model', name='general_equipment_module_attributes__manufacturer_model_name')
+    station_name = django_filters.CharFilter(lookup_type='icontains', label='Station name', name='general_equipment_module_attributes__station_name')
     performing_physician_name = django_filters.CharFilter(lookup_type='icontains', label='Physician')
     accession_number = django_filters.CharFilter(lookup_type='icontains', label='Accession number')
     class Meta:
@@ -58,13 +58,13 @@ class RFSummaryListFilter(django_filters.FilterSet):
         fields = [
             'date_after', 
             'date_before', 
-            'general_equipment_module_attributes__institution_name', 
+            'institution_name', 
             'study_description',
             'patient_age_min',
             'patient_age_max',
-            'general_equipment_module_attributes__manufacturer', 
-            'general_equipment_module_attributes__manufacturer_model_name',
-            'general_equipment_module_attributes__station_name',
+            'manufacturer', 
+            'model_name',
+            'station_name',
             'performing_physician_name',
             'accession_number',
             ]
@@ -96,23 +96,23 @@ class CTSummaryListFilter(django_filters.FilterSet):
     study_description = django_filters.CharFilter(lookup_type='icontains', label='Study description')
     patient_age_min = django_filters.NumberFilter(lookup_type='gt', label='Min age (yrs)', name='patient_study_module_attributes__patient_age_decimal')
     patient_age_max = django_filters.NumberFilter(lookup_type='lt', label='Max age (yrs)', name='patient_study_module_attributes__patient_age_decimal')
-    general_equipment_module_attributes__institution_name = django_filters.CharFilter(lookup_type='icontains', label='Hospital')
-    general_equipment_module_attributes__manufacturer = django_filters.CharFilter(lookup_type='icontains', label='Make')
-    general_equipment_module_attributes__manufacturer_model_name = django_filters.CharFilter(lookup_type='icontains', label='Model')
-    general_equipment_module_attributes__station_name = django_filters.CharFilter(lookup_type='icontains', label='Station name')
+    institution_name = django_filters.CharFilter(lookup_type='icontains', label='Hospital', name='general_equipment_module_attributes__institution_name')
+    manufacturer = django_filters.CharFilter(lookup_type='icontains', label='Make', name='general_equipment_module_attributes__manufacturer')
+    model_name = django_filters.CharFilter(lookup_type='icontains', label='Model', name='general_equipment_module_attributes__manufacturer_model_name')
+    station_name = django_filters.CharFilter(lookup_type='icontains', label='Station name', name='general_equipment_module_attributes__station_name')
     accession_number = django_filters.CharFilter(lookup_type='icontains', label='Accession number')
     class Meta:
         model = General_study_module_attributes
         fields = [
             'date_after', 
             'date_before', 
-            'general_equipment_module_attributes__institution_name', 
+            'institution_name', 
             'study_description',
             'patient_age_min',
             'patient_age_max',
-            'general_equipment_module_attributes__manufacturer', 
-            'general_equipment_module_attributes__manufacturer_model_name',
-            'general_equipment_module_attributes__station_name',
+            'manufacturer', 
+            'model_name',
+            'station_name',
             'accession_number',
             ]
         order_by = (
@@ -142,23 +142,23 @@ class MGSummaryListFilter(django_filters.FilterSet):
     procedure_code_meaning = django_filters.CharFilter(lookup_type='icontains', label='Procedure')
     patient_age_min = django_filters.NumberFilter(lookup_type='gt', label='Min age (yrs)', name='patient_study_module_attributes__patient_age_decimal')
     patient_age_max = django_filters.NumberFilter(lookup_type='lt', label='Max age (yrs)', name='patient_study_module_attributes__patient_age_decimal')
-    general_equipment_module_attributes__institution_name = django_filters.CharFilter(lookup_type='icontains', label='Hospital')
-    general_equipment_module_attributes__manufacturer = django_filters.CharFilter(lookup_type='icontains', label='Manufacturer')
-    general_equipment_module_attributes__manufacturer_model_name = django_filters.CharFilter(lookup_type='icontains', label='Model')
-    general_equipment_module_attributes__station_name = django_filters.CharFilter(lookup_type='icontains', label='Station name')
+    institution_name = django_filters.CharFilter(lookup_type='icontains', label='Hospital', name='general_equipment_module_attributes__institution_name')
+    manufacturer = django_filters.CharFilter(lookup_type='icontains', label='Manufacturer', name='general_equipment_module_attributes__manufacturer')
+    model_name = django_filters.CharFilter(lookup_type='icontains', label='Model', name='general_equipment_module_attributes__manufacturer_model_name')
+    station_name = django_filters.CharFilter(lookup_type='icontains', label='Station name', name='general_equipment_module_attributes__station_name')
     accession_number = django_filters.CharFilter(lookup_type='icontains', label='Accession number')
     class Meta:
         model = General_study_module_attributes
         fields = [
             'date_after', 
             'date_before', 
-            'general_equipment_module_attributes__institution_name', 
+            'institution_name', 
             'procedure_code_meaning',
             'patient_age_min',
             'patient_age_max',
-            'general_equipment_module_attributes__manufacturer', 
-            'general_equipment_module_attributes__manufacturer_model_name',
-            'general_equipment_module_attributes__station_name',
+            'manufacturer', 
+            'model_name',
+            'station_name',
             'accession_number',
             ]
         order_by = (
